==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/lyrics/translations/lyrics_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Şarkı Sözlerini Göster</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Bu eklenti şarkı sözlerini lyricsplugin.com adresinden alır</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="75"/>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="88"/>
        <location filename="../lyricswindow.ui" line="67"/>
        <source>No connection</source>
        <translation>Bağlantı yok</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="91"/>
        <source>Looking up host...</source>
        <translation>Sunucu aranıyor...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="94"/>
        <source>Connecting...</source>
        <translation>Bağlanıyor...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Sending request...</source>
        <translation>İstek gönderiliyor...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="100"/>
        <source>Receiving</source>
        <translation>Alınıyor</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="103"/>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="106"/>
        <source>Closing connection...</source>
        <translation>Bağlantı kapatılıyor...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Şarkı Sözü: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="87"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/General/lyrics/translations/lyrics_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Şarkı Sözlerini Göster</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Bu eklenti şarkı sözlerini lyricsplugin.com adresinden alır</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="63"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="85"/>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Bağlantı yok</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <source>Receiving</source>
        <translation>Alınıyor</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Şarkı Sözü: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Şarkı Sözü Eklentisi</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artist:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
</TS>
